<?php
/**
 * @file
 * Panels IPE-related functions.
 */

/**
 * Implements hook_form_FORM_ID_alter().
 */
function gesso_form_panels_ipe_edit_control_form_alter(&$form, &$form_state, $form_id) {
  // Add form-submit class so IPE styling works.
  foreach ($form['buttons'] as $key => $button) {
    $form['buttons'][$key]['#attributes']['class'][] = 'form-submit';
  }
}

/**
 * Returns HTML for a set of Panels IPE linkbar links.
 */
function gesso_links__panels_ipe_linkbar(&$vars) {
  $links = $vars['links'];
  $attributes = $vars['attributes'];
  $heading = $vars['heading'];
  $only_use_smacss = theme_get_setting('only_use_smacss');
  $show_first_last = theme_get_setting('show_first_last');
  global $language_url;
  $output = '';

  if (count($links) > 0) {
    $output = '';

    // Treat the heading first if it is present to prepend it to the
    // list of links.
    if (!empty($heading)) {
      if (is_string($heading)) {

        // Prepare the array that will be used when the passed heading
        // is a string.
        $heading = array(
          'text' => $heading,

          // Set the default level of the heading.
          'level' => 'h2',
        );
      }
      $output .= '<' . $heading['level'];
      if (!empty($heading['class'])) {
        $output .= drupal_attributes(array('class' => $heading['class']));
      }
      $output .= '>' . check_plain($heading['text']) . '</' . $heading['level'] . '>';
    }

    $output .= '<ul' . drupal_attributes($attributes) . '>';

    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      // Add default core classes for Panels IPE.
      $class = array($key);

      $class[] = 'nav__item';
      $class[] = 'nav__item--' . $key;

      // Add link classes.
      if (isset($link['attributes']['class']) && !is_array($link['attributes']['class'])) {
        $this_class = $link['attributes']['class'];
        $link['attributes']['class'] = array();
        $link['attributes']['class'][] = $this_class;
      }
      $link['attributes']['class'][] = 'nav__link';

      // Add first, last, and active classes to the list of links
      // to help out themers.
      if ($show_first_last && $i == 1) {
        $class[] = 'nav__item--first';

        // Add default core class if wanted.
        if (!$only_use_smacss) {
          $class[] = 'first';
        }
      }
      if ($show_first_last && $i == $num_links) {
        $class[] = 'nav__item--last';

        // Add default core class if wanted.
        if (!$only_use_smacss) {
          $class[] = 'last';
        }
      }
      if (isset($link['href']) && ($link['href'] == $_GET['q'] || ($link['href'] == '<front>' && drupal_is_front_page()))
          && (empty($link['language']) || $link['language']->language == $language_url->language)) {
        $link['attributes']['class'][] = 'is-active';

        // Add default core class if wanted.
        if (!$only_use_smacss) {
          $link['attributes']['class'][] = 'active';
        }
      }

      $output .= '<li' . drupal_attributes(array('class' => $class)) . '>';

      if (isset($link['href'])) {
        // Pass in $link as $options, they share the same keys.
        $output .= l($link['title'], $link['href'], $link);
      }
      elseif (!empty($link['title'])) {
        // Some links are actually not links, but we wrap these in <span>
        // for adding title and class attributes.
        if (empty($link['html'])) {
          $link['title'] = check_plain($link['title']);
        }
        $span_attributes = '';
        if (isset($link['attributes'])) {
          $span_attributes = drupal_attributes($link['attributes']);
        }
        $output .= '<span' . $span_attributes . '>' . $link['title'] . '</span>';
      }

      $i++;
      $output .= "</li>\n";
    }

    $output .= '</ul>';
  }

  return $output;
}
